---
title: <span class="badge builder"></span> DataSourceJsonData
---
# <span class="badge builder"></span> DataSourceJsonData

## Constructor

```python
DataSourceJsonData()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> common.DataSourceJsonData
```

### <span class="badge object-method"></span> alertmanager_uid

```python
def alertmanager_uid(alertmanager_uid: str) -> typing.Self
```

### <span class="badge object-method"></span> auth_type

```python
def auth_type(auth_type: str) -> typing.Self
```

### <span class="badge object-method"></span> default_region

```python
def default_region(default_region: str) -> typing.Self
```

### <span class="badge object-method"></span> manage_alerts

```python
def manage_alerts(manage_alerts: bool) -> typing.Self
```

### <span class="badge object-method"></span> profile

```python
def profile(profile: str) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [DataSourceJsonData](./object-DataSourceJsonData.md)
